@@ -28,6 +28,7 @@
 
 #include "weston-test-client-helper.h"
 #include "weston-test-fixture-compositor.h"
+#include "weston-test-assert.h"
 
 static enum test_result_code
 fixture_setup(struct weston_test_harness *harness)
@@ -60,9 +61,9 @@ check_client_move(struct client *client, int x, int y)
 	move_client_offscreenable(client, x, y);
 
 	if (output_contains_client(client)) {
-		assert(client->surface->output == client->output);
+		test_assert_ptr_eq(client->surface->output, client->output);
 	} else {
-		assert(client->surface->output == NULL);
+		test_assert_ptr_null(client->surface->output);
 	}
 }
 
@@ -72,9 +73,9 @@ TEST(test_surface_output)
 	int x, y;
 
 	client = create_client_and_test_surface(100, 100, 100, 100);
-	assert(client);
+	test_assert_ptr_not_null(client);
 
-	assert(output_contains_client(client));
+	test_assert_true(output_contains_client(client));
 
 	/* not visible */
 	x = 0;
@@ -99,19 +100,21 @@ TEST(test_surface_output)
 
 	/* visible */
 	check_client_move(client, --x, y);
-	assert(output_contains_client(client));
+	test_assert_true(output_contains_client(client));
 
 	/* not visible */
 	x = 0;
 	y = client->output->height;
 	check_client_move(client, x, y);
-	assert(!output_contains_client(client));
+	test_assert_false(output_contains_client(client));
 
 	/* visible */
 	check_client_move(client, x, --y);
-	assert(output_contains_client(client));
+	test_assert_true(output_contains_client(client));
 
 	client_destroy(client);
+
+	return RESULT_OK;
 }
 
 static void
@@ -133,22 +136,25 @@ TEST(buffer_release)
 	struct buffer *buf1;
 	struct buffer *buf2;
 	struct buffer *buf3;
+	pixman_color_t black;
 	int buf1_released = 0;
 	int buf2_released = 0;
 	int buf3_released = 0;
 	int frame;
 
+	color_rgb888(&black, 0, 0, 0);
+
 	client = create_client_and_test_surface(100, 100, 100, 100);
-	assert(client);
+	test_assert_ptr_not_null(client);
 	surface = client->surface->wl_surface;
 
-	buf1 = create_shm_buffer_a8r8g8b8(client, 100, 100);
+	buf1 = create_shm_buffer_solid(client, 100, 100, &black);
 	wl_buffer_add_listener(buf1->proxy, &buffer_listener, &buf1_released);
 
-	buf2 = create_shm_buffer_a8r8g8b8(client, 100, 100);
+	buf2 = create_shm_buffer_solid(client, 100, 100, &black);
 	wl_buffer_add_listener(buf2->proxy, &buffer_listener, &buf2_released);
 
-	buf3 = create_shm_buffer_a8r8g8b8(client, 100, 100);
+	buf3 = create_shm_buffer_solid(client, 100, 100, &black);
 	wl_buffer_add_listener(buf3->proxy, &buffer_listener, &buf3_released);
 
 	/*
@@ -161,28 +167,30 @@ TEST(buffer_release)
 	frame_callback_set(surface, &frame);
 	wl_surface_commit(surface);
 	frame_callback_wait(client, &frame);
-	assert(buf1_released == 0);
+	test_assert_int_eq(buf1_released, 0);
 	/* buf2 may or may not be released */
-	assert(buf3_released == 0);
+	test_assert_int_eq(buf3_released, 0);
 
 	wl_surface_attach(surface, buf3->proxy, 0, 0);
 	frame_callback_set(surface, &frame);
 	wl_surface_commit(surface);
 	frame_callback_wait(client, &frame);
-	assert(buf1_released == 0);
-	assert(buf2_released == 1);
+	test_assert_int_eq(buf1_released, 0);
+	test_assert_int_eq(buf2_released, 1);
 	/* buf3 may or may not be released */
 
 	wl_surface_attach(surface, client->surface->buffer->proxy, 0, 0);
 	frame_callback_set(surface, &frame);
 	wl_surface_commit(surface);
 	frame_callback_wait(client, &frame);
-	assert(buf1_released == 0);
-	assert(buf2_released == 1);
-	assert(buf3_released == 1);
+	test_assert_int_eq(buf1_released, 0);
+	test_assert_int_eq(buf2_released, 1);
+	test_assert_int_eq(buf3_released, 1);
 
 	buffer_destroy(buf1);
 	buffer_destroy(buf2);
 	buffer_destroy(buf3);
 	client_destroy(client);
+
+	return RESULT_OK;
 }
