@@ -30,6 +30,7 @@
 
 #include "weston-test-client-helper.h"
 #include "weston-test-fixture-compositor.h"
+#include "weston-test-assert.h"
 #include "image-iter.h"
 #include "test-config.h"
 
@@ -90,7 +91,7 @@ TEST(internal_screenshot)
 	/* Create the client */
 	testlog("Creating client for test\n");
 	client = create_client_and_test_surface(100, 100, 100, 100);
-	assert(client);
+	test_assert_ptr_not_null(client);
 	surface = client->surface->wl_surface;
 
 	/*
@@ -119,21 +120,21 @@ TEST(internal_screenshot)
 
 	/* Take a snapshot.  Result will be in screenshot->wl_buffer. */
 	testlog("Taking a screenshot\n");
-	screenshot = capture_screenshot_of_output(client, NULL);
-	assert(screenshot);
+	screenshot = capture_screenshot_of_output(client, NULL, NO_DECORATIONS);
+	test_assert_ptr_not_null(screenshot);
 
 	/* Load good reference image */
 	fname = screenshot_reference_filename("internal-screenshot-good", 0);
 	testlog("Loading good reference image %s\n", fname);
 	reference_good = load_image_from_png(fname);
-	assert(reference_good);
+	test_assert_ptr_not_null(reference_good);
 	free(fname);
 
 	/* Load bad reference image */
 	fname = screenshot_reference_filename("internal-screenshot-bad", 0);
 	testlog("Loading bad reference image %s\n", fname);
 	reference_bad = load_image_from_png(fname);
-	assert(reference_bad);
+	test_assert_ptr_not_null(reference_bad);
 	free(fname);
 
 	/* Test check_images_match() without a clip.
@@ -141,7 +142,7 @@ TEST(internal_screenshot)
 	 */
 	match = check_images_match(screenshot->image, reference_bad, NULL, NULL);
 	testlog("Screenshot %s reference image\n", match? "equal to" : "different from");
-	assert(!match);
+	test_assert_false(match);
 	pixman_image_unref(reference_bad);
 
 	/* Test check_images_match() with clip.
@@ -174,8 +175,10 @@ TEST(internal_screenshot)
 	buffer_destroy(screenshot);
 
 	testlog("Test complete\n");
-	assert(match);
+	test_assert_true(match);
 
 	buffer_destroy(buf);
 	client_destroy(client);
+
+	return RESULT_OK;
 }
